@@ -10,7 +10,7 @@
     meta <- packageDescription("sn")
     packageStartupMessage(
       "Package 'sn', ", meta$Version, " (", meta$Date, "). ",
-      "Type 'help(SN)' for summary information.\n",
+      "Type 'help(SN)' and 'help(overview-sn)' for basic information.\n",
       "The package redefines function 'sd' but its usual working is unchanged.")
   }
   invisible()
